@@ -22,17 +22,17 @@ char *fake = N_("Division w/o remainder");
 char *fake = N_("Check if argument is a gaussian integer");
 char *fake = N_("Return the sign (-1,0,1)");
 char *fake = N_("Logarithm of any base (calls DiscreteLog if in modulo mode), if base is not given, e is used");
-char *fake = N_("The arccos (reverse cos) function");
-char *fake = N_("The arccosh (reverse cosh) function");
-char *fake = N_("The arccot (reverse cot) function");
-char *fake = N_("The arccoth (reverse coth) function");
-char *fake = N_("The reverse cosecant function");
-char *fake = N_("The reverse hyperbolic cosecant function");
-char *fake = N_("The reverse secant function");
-char *fake = N_("The reverse hyperbolic secant function");
-char *fake = N_("The arcsin (reverse sin) function");
-char *fake = N_("The arcsinh (reverse sinh) function");
-char *fake = N_("The arctanh (reverse tanh) function");
+char *fake = N_("The arccos (inverse cos) function");
+char *fake = N_("The arccosh (inverse cosh) function");
+char *fake = N_("The arccot (inverse cot) function");
+char *fake = N_("The arccoth (inverse coth) function");
+char *fake = N_("The inverse cosecant function");
+char *fake = N_("The inverse hyperbolic cosecant function");
+char *fake = N_("The inverse secant function");
+char *fake = N_("The inverse hyperbolic secant function");
+char *fake = N_("The arcsin (inverse sin) function");
+char *fake = N_("The arcsinh (inverse sinh) function");
+char *fake = N_("The arctanh (inverse tanh) function");
 char *fake = N_("The cotangent function");
 char *fake = N_("The hyperbolic cotangent function");
 char *fake = N_("The cosecant function");
@@ -76,7 +76,7 @@ char *fake = N_("Remove column(s) and row(s) from a matrix");
 char *fake = N_("Calculate the kth compund matrix of A");
 char *fake = N_("Delete a column of a matrix");
 char *fake = N_("Delete a row of a matrix");
-char *fake = N_("Get the dot product of two vectors");
+char *fake = N_("Get the dot product of two vectors (no conjugates)");
 char *fake = N_("Is a matrix diagonal");
 char *fake = N_("Is a matrix lower triangular");
 char *fake = N_("Is a matrix upper triangular");
@@ -91,7 +91,6 @@ char *fake = N_("Reverse elements in a vector");
 char *fake = N_("Calculate sum of each row in a matrix");
 char *fake = N_("Calculate sum of squares of each row in a matrix");
 char *fake = N_("Sort vector elements");
-char *fake = N_("Removes any all-zero columns of M");
 char *fake = N_("Removes any all-zero rows of M");
 char *fake = N_("Return column(s) and row(s) from a matrix");
 char *fake = N_("Swap two rows in a matrix");
@@ -111,8 +110,7 @@ char *fake = N_("Get the determinantal divisors of an integer matrix (not its ch
 char *fake = N_("Direct sum of matrices");
 char *fake = N_("Direct sum of a vector of matrices");
 char *fake = N_("Get the eigenvalues of a matrix (Currently only for 2x2 and triangular matrices)");
-char *fake = N_("Apply the Gram-Schmidt process (to the columns) with respect to innter product given by #2");
-char *fake = N_("Apply the Gram-Schmidt process (to the columns) using the dot product");
+char *fake = N_("Apply the Gram-Schmidt process (to the columns) with respect to inner product given by B (if not given use hermitian product)");
 char *fake = N_("Hankel matrix");
 char *fake = N_("Hilbert matrix of order n");
 char *fake = N_("Get the image (columnspace) of a linear transform");
@@ -136,7 +134,8 @@ char *fake = N_("Get the nullspace of a matrix");
 char *fake = N_("Get the nullity of a matrix");
 char *fake = N_("Get the orthogonal complement of the columnspace");
 char *fake = N_("Return pivot columns of a matrix, that is columns which have a leading 1 in rref form, also returns the row where they occur");
-char *fake = N_("Projection of vector v onto subspace W given a bilinear form B");
+char *fake = N_("Projection of vector v onto subspace W given a sesquilinear form B (if not given use hermitian product)");
+char *fake = N_("Get the QR decomposition of A, returns R and Q can be a reference");
 char *fake = N_("Return the Raleigh Quotient of a matrix and a vector");
 char *fake = N_("Get the rank of a matrix");
 char *fake = N_("Rosser matrix, a classic symmetric eigenvalue test problem");
@@ -145,6 +144,8 @@ char *fake = N_("Rotation around origin in R^3 about the x-axis");
 char *fake = N_("Rotation around origin in R^3 about the y-axis");
 char *fake = N_("Rotation around origin in R^3 about the z-axis");
 char *fake = N_("Get a basis matrix for the rowspace of a matrix");
+char *fake = N_("Evaluate (v,w) with respect to the sesquilinear form given by the matrix A");
+char *fake = N_("Return a function that evaluates two vectors with respect to the sesquilinear form given by A");
 char *fake = N_("Smith Normal Form for fields (will end up with 1's on the diagonal)");
 char *fake = N_("Smith Normal Form for square integer matrices (not its characteristic)");
 char *fake = N_("Calculate the trace of a matrix");
@@ -228,10 +229,7 @@ char *fake = N_("Calculate the population standard deviations of rows of a matri
 char *fake = N_("Calculate the standard deviations of rows of a matrix and return a vertical vector");
 char *fake = N_("Calculate the standard deviation of a whole matrix");
 char *fake = N_("Run newton's method on a polynomial to attempt to find a root, returns after two successive values are within epsilon or after maxn tries (then returns null)");
-char *fake = N_("Returns a set theoretic intersection of X and Y (X and Y are vectors pretending to be sets)");
-char *fake = N_("Returns true if the element x is in the set X (where X is a vector pretending to be a set)");
 char *fake = N_("Returns a set where every element of X appears only once");
-char *fake = N_("Returns a set theoretic difference X-Y (X and Y are vectors pretending to be sets)");
 char *fake = N_("Returns a set theoretic union of X and Y (X and Y are vectors pretending to be sets)");
 char *fake = N_("Attempt to symbolically differentiate a function n times");
 char *fake = N_("Attempt to symbolically differentiate a function n times quietly and return null on failure");
